%define ALD_Ver		2.0

#USE gcc-7.5.0

%define OrgName musl

Name:         %{OrgName}
License:      MIT
Summary:      The musl libc static C libraries
Version:      1.2.4
Release:      0s

#https://musl.libc.org/releases/musl-1.2.4.tar.gz

Source: %{OrgName}-%{version}.tar.xz
Source1: %{OrgName}-%{version}-patches.tgz

%define DestDir		/Embedded/mC/%{version}s

%define _prefix /usr/mC/%{version}s
#define _lib lib
# -----------------------------------------------------
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}/mC/%{version}s
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

# -----------------------------------------------------

%if %{have_auto_local}
%define __os_install_post %{nil}
%else
%define MakeLocCross 0
%endif

%if %{_CROSS}
%define CrossPath /cross/%{_target_cpu}
%else
%define CrossPath %{nil}
%endif

#------------------ CROSS DIR --------------------

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
musl libc - a Small C Library for Linux
# --------------------------------------
%package %{_target_cpu}
Summary:      %{name} Cross-%{_target_cpu}
Buildarch:    noarch
autoreqprov:  0
%description %{_target_cpu}
%{name} Cross-%{_target_cpu}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

tar -xzf %SOURCE1
patch -b -z .orig -p0<patches/min_iconv.patch

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
export PATH=$PATH:%{CrossPath}/bin
export GCC_NoHostPath=d
export CC="%{_host}-gcc"
%else
export CC="gcc"
%endif

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i586 -mpreferred-stack-boundary=3 -falign-functions=4 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

#OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables"
export CFLAGS=$OPTFLAGS

./configure \
%if %{_CROSS}
  --target=%{_host} \
%endif
  --prefix=%{_prefix} \
  --exec-prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --includedir=%{_includedir} \
  --disable-shared \
  &>FConfigure_log.txt


make  &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export PATH=$PATH:%{CrossPath}/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

cp -a COPYRIGHT README $RPM_BUILD_ROOT%{docdir}/
#ln -s /usr/share/doc/lgpl-2.1.txt $RPM_BUILD_ROOT%{docdir}/COPYING.LIB
cp $RPM_BUILD_ROOT%{_bindir}/musl-gcc $RPM_BUILD_ROOT%{_bindir}/%{_arch}-%{_os}-musl-gcc
 
%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross}
%endif  # have_auto_local

ln -s /usr/include/asm $RPM_BUILD_ROOT%{_includedir}/asm
ln -s /usr/include/asm-generic $RPM_BUILD_ROOT%{_includedir}/asm-generic
ln -s /usr/include/linux $RPM_BUILD_ROOT%{_includedir}/linux

pushd $RPM_BUILD_ROOT/%{_bindir}
for sf in addr2line ar as cpp nm objcopy objdump ranlib size strings strip; do
  ln -s /usr/bin/$sf %{_target_cpu}-linux-musl-$sf
done
popd

%if %{MakeLocCross} && %{have_auto_local}
ln -s %{CrossPath}/usr/include/asm $RPM_BUILD_ROOT%{CrossPath}%{_includedir}/asm
ln -s %{CrossPath}/usr/include/asm-generic $RPM_BUILD_ROOT%{CrossPath}%{_includedir}/asm-generic
ln -s %{CrossPath}/usr/include/linux $RPM_BUILD_ROOT%{CrossPath}%{_includedir}/linux

pushd $RPM_BUILD_ROOT/%{CrossPath}%{_bindir}
for sf in addr2line ar as cpp nm objcopy objdump ranlib size strings strip; do
  ln -s %{CrossPath}/bin/%{_host}-$sf %{_target_cpu}-linux-musl-$sf
done
rm -f musl-gcc

cat > arm-linux-musl-gcc <<EOF
#! /bin/sh
export PATH=%{CrossPath}/bin:\$PATH
%{CrossPath}/bin/%{_host}-gcc "\$@"  -specs "%{CrossPath}%{_libdir}/musl-gcc.specs"
EOF

cp arm-linux-musl-gcc musl-gcc

popd

sed -i s:"/usr/mC":"%{CrossPath}/usr/mC": $RPM_BUILD_ROOT/%{CrossPath}%{_libdir}/musl-gcc.specs
sed -i s:" /usr/mC":" %{CrossPath}/usr/mC": $RPM_BUILD_ROOT/%{CrossPath}%{_libdir}/musl-gcc.specs
sed -i s:"/lib/crtn.o":"/lib/crtn.o -lc": $RPM_BUILD_ROOT/%{CrossPath}%{_libdir}/musl-gcc.specs



%endif

# ------------------- Clean ------------------------------------------
%Clean
%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%Files
/usr

# ------------------- Cross Files ------------------------------------
%if %{MakeLocCross} && %{have_auto_local}

%files %{_target_cpu}
%{CrossPath}

%endif # MakeLocCross
